@@ -29,7 +29,7 @@ protect_math <- function(body, ns = md_ns()) {
 }
 
 set_asis <- function(nodes) {
-  xml2::xml_set_attr(nodes[xml2::xml_name(nodes) != "softbreak"], "asis", "true")
+  xml2::xml_set_attr(nodes, "asis", "true")
 }
 
 # INLINE MATH ------------------------------------------------------------------
@@ -52,7 +52,7 @@ inline_dollars_regex <- function(type = c("start", "stop", "full")) {
   # they do not consume the string
   # (https://junli.netlify.app/en/overlapping-regular-expression-in-python/)
   #
-  # This looks for a potetial minus sign followed by maybe a space to allow for
+  # This looks for a potential minus sign followed by maybe a space to allow for
   # $\beta, $$\beta, $-\beta, $- \beta
   minus_maybe <- glue::glue("(?=([-][{ace}]?)?")
   # punctuation marks that should _not_ occur after the dollar sign. I'm listing
@@ -64,7 +64,7 @@ inline_dollars_regex <- function(type = c("start", "stop", "full")) {
   switch(type,
     start = start,
     stop = stop,
-    full = glue::glue('({start}.+?{stop})')
+    full = glue::glue('({start}.*?{stop})')
   )
 }
 
@@ -97,11 +97,11 @@ find_broken_math <- function(math) {
 #'   "This sentence contains $I_A$ $\\frac{\\pi}{2}$ inline $\\LaTeX$ math."
 #' )
 #' txt <- xml2::read_xml(txt)
-#' cat(tinkr::to_md(list(body = txt, yaml = "")), sep = "\n")
+#' cat(tinkr::to_md(list(body = txt, frontmatter = "")), sep = "\n")
 #' ns  <- tinkr::md_ns()
 #' if (requireNamespace("withr")) {
 #' protxt <- withr::with_namespace("tinkr", protect_inline_math(txt, ns))
-#' cat(tinkr::to_md(list(body = protxt, yaml = "")), sep = "\n")
+#' cat(tinkr::to_md(list(body = protxt, frontmatter = "")), sep = "\n")
 #' }
 protect_inline_math <- function(body, ns) {
   body  <- copy_xml(body)
@@ -109,6 +109,7 @@ protect_inline_math <- function(body, ns) {
   if (length(math) == 0) {
     return(body)
   }
+
   broke <- find_broken_math(math)
 
   bespoke  <- !(broke$no_end | broke$no_beginning | broke$ambiguous)
@@ -143,6 +144,11 @@ protect_inline_math <- function(body, ns) {
     # an error.
     le <- length(bmath[endless])
     lh <- length(bmath[headless])
+    # 2024-10-10: if the number of headless OR endless tags is zero, then we
+    # are dealing with currency. See issue #121 and #124
+    if (lh == 0 || le == 0) {
+      return(copy_xml(body))
+    }
     if (le != lh) {
       unbalanced_math_error(bmath, endless, headless, le, lh)
     }
@@ -177,8 +183,8 @@ fix_partial_inline <- function(tag, body, ns) {
   # paste the lines together and create new nodes
   n <- length(math_lines)
   char <- as.character(math_lines)
-  char[[1]] <- sub("[$]", "$</text><text asis='true'>", char[[1]])
-  char[[n]] <- sub("[<]text ", "<text asis='true' ", char[[n]])
+  char[[1]] <- sub("[$]", "$</text><text asis='true' math='true'>", char[[1]])
+  char[[n]] <- sub("[<]text ", "<text asis='true' math='true' ", char[[n]])
   nodes <- paste(char, collapse = "")
   nodes <- make_text_nodes(nodes)
   # add the new nodes to the bottom of the existing math lines
@@ -197,7 +203,7 @@ fix_fully_inline <- function(math) {
   # <text>this is </text><text asis='true'>$\LaTeX$</text><text> text</text>
   char <- gsub(
     pattern = inline_dollars_regex("full"),
-    replacement = "</text><text asis='true'>\\1</text><text>",
+    replacement = "</text><text asis='true' math='true'>\\1</text><text>",
     x = char,
     perl = TRUE
   )
@@ -245,7 +251,12 @@ make_text_nodes <- function(txt) {
 # BLOCK MATH ------------------------------------------------------------------
 
 find_block_math <- function(body, ns) {
-  find_between(body, ns, pattern = "md:text[contains(text(), '$$')]", include = FALSE)
+  # https://github.com/ropensci/tinkr/issues/113#issue-2302065427
+  find_between(body,
+    ns,
+    pattern = "md:text[contains(text(), '$$')]",
+    include = TRUE
+  )
 }
 
 find_between_inlines <- function(body, ns, tag) {
@@ -258,6 +269,7 @@ protect_block_math <- function(body, ns) {
   # get all of the internal nodes
   bm <- xml2::xml_find_all(bm, ".//descendant-or-self::md:*", ns = ns)
   set_asis(bm)
+  xml2::xml_set_attr(bm, "math", "true")
 }
 
 # TICK BOXES -------------------------------------------------------------------
@@ -289,7 +301,7 @@ protect_tickbox <- function(body, ns) {
 #' Protect unescaped square brackets from being escaped
 #'
 #' Commonmark allows both `[unescaped]` and `\[escaped\]` square brackets, but
-#' in the XML representation, it makes no note of which square brackets were 
+#' in the XML representation, it makes no note of which square brackets were
 #' originally escaped and thus will escape both in the output. This function
 #' protects brackets that were unescaped in the source document from being
 #' escaped.
@@ -297,12 +309,12 @@ protect_tickbox <- function(body, ns) {
 #' @inheritParams resolve_anchor_links
 #' @keywords internal
 #'
-#' @details 
+#' @details
 #'
 #' This is an **internal function** that is run by default via `to_xml()` and
 #' `yarn$new()`. It uses the original document, parsed as text, to find and
 #' protect unescaped square brackets from being escaped in the output.
-#' 
+#'
 #' ## Example: child documents and footnotes
 #'
 #' For example, let's say you have two R Markdown documents, one references the
@@ -328,7 +340,7 @@ protect_tickbox <- function(body, ns) {
 #' ...
 #' [reflink]: https://example.com
 #' ```
-#' 
+#'
 #' Without protection, the roundtripped index.Rmd document would look like this:
 #'
 #' ````markdown
@@ -349,15 +361,15 @@ protect_tickbox <- function(body, ns) {
 #'
 #' @note Because the This `body` to be an XML document with `sourcepos` attributes on the
 #'   nodes, which is achieved by using `sourcepos = TRUE` with [to_xml()] or
-#'   [yarn]. 
+#'   [yarn].
 #'
 #' @examples
 #' f <- system.file("extdata", "link-test.md", package = "tinkr")
 #' md <- yarn$new(f, sourcepos = TRUE, unescaped = FALSE)
 #' md$show()
 #' if (requireNamespace("withr")) {
-#' lines <- readLines(f)[-length(md$yaml)]
-#' lnks <- withr::with_namespace("tinkr", 
+#' lines <- readLines(f)[-length(md$frontmatter)]
+#' lnks <- withr::with_namespace("tinkr",
 #'   protect_unescaped(body = md$body, txt = lines))
 #' md$body <- lnks
 #' md$show()
@@ -384,7 +396,7 @@ protect_unescaped <- function(body, txt, ns = md_ns()) {
 #' @param txt a vector of text
 #' @return the same output as [base::gregexpr()]: a list the same length as
 #' `txt` with integer vectors indicating the character positions of the matches
-#' with attributes: 
+#' with attributes:
 #'   1. match.length the length of the match (will be '2')
 #' @noRd
 find_escaped_squares <- function(txt) {
@@ -408,8 +420,8 @@ find_escaped_squares <- function(txt) {
 #'
 #' Knowing this, we can process each node by its line number and wrap all
 #' unescpaed square braces in text nodes with the `@asis` attribute, which is
-#' performed with the [fix_unescaped()] function.
-#' 
+#' performed with the fix_unescaped() function.
+#'
 #' @return nothing, invisibly. This function is called for its side-effect.
 #' @noRd
 fix_unescaped_squares <- function(nodes, txt) {
@@ -445,13 +457,13 @@ fix_unescaped_squares <- function(nodes, txt) {
 #'
 #' This will convert unescaped square braces to individual text nodes with an
 #' `asis` attribute to prevent these from being escaped in the output.
-#' 
+#'
 #' For example, markdown like this:
 #'
 #' ```markdown
 #' this is [unescaped] and this is \[escaped\]
 #' ```
-#' 
+#'
 #' will produce a text node like this:
 #'
 #' ```html
@@ -467,7 +479,7 @@ fix_unescaped_squares <- function(nodes, txt) {
 #' <text asis='true'>]</text>
 #' <text> and this is [escaped]</text>
 #' ```
-#' 
+#'
 #' This will ensure that the unescaped markdown remains unescaped.
 #'
 #' @param node a text node that contains square braces
@@ -481,7 +493,7 @@ fix_unescaped_squares <- function(nodes, txt) {
 #' @return new XML nodes, invisibly
 #' @noRd
 fix_unescaped <- function(node, escaped = integer(0), offset = 1L) {
-  
+
   txt <- as.character(node)
   if (length(escaped) == 0) {
     # If we have no escaped characters, then we can do a broad substitution
@@ -491,7 +503,7 @@ fix_unescaped <- function(node, escaped = integer(0), offset = 1L) {
     # the position is based on the actual text, we need to find the start of
     # the actual text in the node text
     text_start <- gregexpr("[>]", txt)[[1]][[1]] + 1L
-    # Because the escaped characters were stripped off, we have to account for 
+    # Because the escaped characters were stripped off, we have to account for
     # a rolling count of the number of escapes
     missing_chars <- seq_along(escaped) - 1L
     # If the source starts with markup, we have to take into account the offset
@@ -502,8 +514,8 @@ fix_unescaped <- function(node, escaped = integer(0), offset = 1L) {
   # the unescaped braces.
   chars <- strsplit(txt, "")[[1]]
   chars[unescaped] <- sub(
-    pattern = "(\\[|\\])", 
-    replacement = "</text><text asis='true'>\\1</text><text>", 
+    pattern = "(\\[|\\])",
+    replacement = "</text><text asis='true'>\\1</text><text>",
     x = chars[unescaped]
   )
   new_nodes <- make_text_nodes(paste(chars, collapse = ""))
