@@ -1,6 +1,7 @@
-#' Write YAML and XML back to disk as (R)Markdown
+#' Write front-matter (YAML, TOML or JSON) and XML back to disk as (R)Markdown
 #'
-#' @param yaml_xml_list result from a call to [to_xml()] and editing.
+#' @param frontmatter_xml_list result from a call to [to_xml()] and editing.
+#' @param yaml_xml_list `r lifecycle::badge('deprecated')` Use `frontmatter_xml_list()`.
 #' @param path path of the new file. Defaults to `NULL`, which will not write
 #'   any file, but will still produce the conversion and pass the output as
 #'   a character vector.
@@ -13,34 +14,46 @@
 #' the path to your XSL stylesheet as argument.
 #'
 #'
-#' @return the converted document, invisibly. 
+#' @return
+#'  - `to_md()`: `\[character\]` the converted document, invisibly as a character vector containing two elements: the frontmatter list and the markdown body.
+#'  - `to_md_vec()`: `\[character\]` the markdown representation of each node.
 #'
 #' @export
 #'
 #' @examples
 #' path <- system.file("extdata", "example1.md", package = "tinkr")
-#' yaml_xml_list <- to_xml(path)
-#' names(yaml_xml_list)
-#' library("magrittr")
+#' frontmatter_xml_list <- to_xml(path)
+#' names(frontmatter_xml_list)
+#' # extract the level 3 headers from the body
+#' headers3 <- xml2::xml_find_all(
+#'   frontmatter_xml_list$body,
+#'   xpath = './/md:heading[@level="3"]',
+#'   ns = md_ns()
+#' )
+#' # show the headers
+#' print(h3 <- to_md_vec(headers3))
 #' # transform level 3 headers into level 1 headers
-#' body <- yaml_xml_list$body
-#' body %>%
-#'   xml2::xml_find_all(xpath = './/d1:heading',
-#'                      xml2::xml_ns(.)) %>%
-#'   .[xml2::xml_attr(., "level") == "3"] -> headers3
+#' # NOTE: these nodes are still associated with the document and this is done
+#' # in place.
 #' xml2::xml_set_attr(headers3, "level", 1)
-#' yaml_xml_list$body <- body
+#' # preview the new headers
+#' print(h1 <- to_md_vec(headers3))
 #' # save back and have a look
 #' newmd <- tempfile("newmd", fileext = ".md")
-#' to_md(yaml_xml_list, newmd)
+#' res <- to_md(frontmatter_xml_list, newmd)
+#' # show that it works
+#' regmatches(res[[2]], gregexpr(h1[1], res[[2]], fixed = TRUE))
 #' # file.edit("newmd.md")
 #' file.remove(newmd)
 #'
-to_md <- function(yaml_xml_list, path = NULL, stylesheet_path = stylesheet()){
+to_md <- function(frontmatter_xml_list,
+                  path = NULL,
+                  stylesheet_path = stylesheet(),
+                  yaml_xml_list = deprecated()){
 
   # duplicate document to avoid overwriting
-  body <- copy_xml(yaml_xml_list$body)
-  yaml <- yaml_xml_list$yaml
+  body <- copy_xml(frontmatter_xml_list$body)
+  frontmatter <- frontmatter_xml_list$frontmatter
 
   # read stylesheet and fail early if it doesn't exist
   stylesheet <- read_stylesheet(stylesheet_path)
@@ -48,7 +61,7 @@ to_md <- function(yaml_xml_list, path = NULL, stylesheet_path = stylesheet()){
   transform_code_blocks(body)
   remove_phantom_text(body)
 
-  md_out <- transform_to_md(body, yaml, stylesheet)
+  md_out <- transform_to_md(body, frontmatter, stylesheet)
 
   if (!is.null(path)) {
     writeLines(md_out, con = path, useBytes = TRUE, sep =  "\n\n")
@@ -57,15 +70,29 @@ to_md <- function(yaml_xml_list, path = NULL, stylesheet_path = stylesheet()){
   invisible(md_out)
 }
 
-# convert body and yaml to markdown text given a stylesheet
-transform_to_md <- function(body, yaml, stylesheet) {
+#' @rdname to_md
+#' @export
+#' @param nodelist an object of `xml_nodelist` or `xml_node`
+to_md_vec <- function(nodelist, stylesheet_path = stylesheet()) {
+  if (inherits(nodelist, "xml_node")) {
+    nodelist <- list(nodelist)
+  }
+  nodes <- lapply(nodelist, function(i) {
+    print_lines(isolate_nodes(i, "list")$doc, stylesheet = stylesheet_path)
+  })
+  trimws(vapply(nodes, paste, character(1), collapse = "\n"))
+}
+
+
+# convert body and frontmatter to markdown text given a stylesheet
+transform_to_md <- function(body, frontmatter, stylesheet) {
   body <- xslt::xml_xslt(body, stylesheet = stylesheet)
 
-  if (length(yaml) > 0) {
-    yaml <- glue::glue_collapse(yaml, sep = "\n")
+  if (length(frontmatter) > 0) {
+    frontmatter <- glue::glue_collapse(frontmatter, sep = "\n")
   }
 
-  c(yaml, body)
+  c(frontmatter, body)
 }
 
 # remove phantom text nodes that occur before links, images, and asis nodes that
@@ -127,3 +154,4 @@ to_info <- function(code_block){
 
  xml2::xml_set_attr(code_block, "info", info)
 }
+
